@@ -1,10 +1,6 @@
-try:
-    from urllib.request import urlopen
-except ImportError:
-    from urllib2 import urlopen
+from __future__ import generator_stop
+from urllib.request import urlopen
 import json
-from future import standard_library
-standard_library.install_aliases()
 
 
 def get_my_ip():
@@ -20,10 +16,10 @@ def get_my_ip():
 
 
 def colorize(target, color, use_escape=True):
-    ''' Colorize target string. Set use_escape to false when text will not be
-    interpreted by readline, such as in intro message.'''
+    """ Colorize target string. Set use_escape to false when text will not be
+    interpreted by readline, such as in intro message."""
     def escape(code):
-        ''' Escape character '''
+        """ Escape character """
         return '\001%s\002' % code
     if color == 'purple':
         color_code = '\033[95m'
